@@ -1,6 +1,6 @@
 /* folder_to_xml.c - file system to xml convertion for sciteproj
  *
- *  Copyright 2009 Andreas Ronnquist
+ *  Copyright 2009,2010 Andreas Ronnquist
  *
  * This file is part of Sciteproj.
  * 
@@ -23,6 +23,9 @@
 #include <gtk/gtk.h>
 #include <string.h>
 
+#include <glib.h>
+#include <glib/gstdio.h>
+
 #include <unistd.h>
 
 #include "folder_to_xml.h"
@@ -51,6 +54,11 @@ gchar *get_short_folder_name(gchar *base,gchar *current)
 		result++;
 	}
 	
+	// make sure the returned string don't start with a dir separator
+	if (result[0]==G_DIR_SEPARATOR) {
+		result++;
+	}
+		
 	return result;
 }
 
@@ -149,10 +157,10 @@ gboolean traverse_folder(gchar *folder,int *indent,gboolean ignore_hidden,int ma
 					gchar *folder=get_short_folder_name(stored_current_dir,current_dir);
 					
 					if ((folder!=NULL) && ((int)(strlen(folder))!=0)) {
-						//g_printf("<file>./%s/%s</file>\n",folder,file);
+						
 						if (save_file!=NULL) fprintf(save_file,"<file>./%s/%s</file>\n",folder,file);
 					} else {
-						//g_printf("<file>./%s</file>\n",file);
+						
 						if (save_file!=NULL) fprintf(save_file,"<file>./%s</file>\n",file);
 					}
 				}
@@ -173,13 +181,18 @@ gboolean traverse_folder(gchar *folder,int *indent,gboolean ignore_hidden,int ma
 
 	print_indent(newin);
 	//g_printf("</group>\n");
-	if (save_file!=NULL) fprintf(save_file,"</group>\n");
+	if (save_file!=NULL) {
+		fprintf(save_file,"</group>\n");
+	}
 						
 	if (g_chdir("..")!=0) {
 		return FALSE;
 	}
 						
 	(*indent)--;
+	
+	// success
+	return TRUE;
 }
 
 /**
