@@ -83,6 +83,8 @@ static void removeitem_menu_cb();
 static void sort_ascending_cb();
 static void sort_descending_cb();
 
+static void copy_filename_to_clipboard_cb();
+
 static void edit_options_cb();
 
 gboolean is_name_valid(gchar *instring);
@@ -126,6 +128,7 @@ static gchar *sMenuDefXML = (gchar*)\
 		<popup name=\"FilePopup\" action=\"FilePopupAction\"> \
 			<menuitem name=\"OpenFilePopupItem\" action=\"OpenFilePopupAction\"/> \
 			<menuitem name=\"RemoveFilePopupItem\" action=\"RemoveFilePopupAction\"/> \
+			<menuitem name=\"CopyFilenameToClipBoard\" action=\"CopyFilenameToClipBoardAction\"/> \
 			<separator/> \
 			<menuitem name=\"PropertiesPopupItem\" action=\"PropertiesPopupAction\"/> \
 		</popup> \
@@ -179,6 +182,7 @@ static GtkActionEntry sMenuActions[] =
 	
 	{ "OpenFilePopupAction", GTK_STOCK_OPEN, "Open File in SciTE", "", "Open a file in SciTE", G_CALLBACK(popup_open_file_cb) },
 	{ "RemoveFilePopupAction", GTK_STOCK_DELETE, "Remove File From Project", "", "Remove a file from the project", G_CALLBACK(popup_remove_node_cb) },
+	{ "CopyFilenameToClipBoardAction", GTK_STOCK_COPY, "Copy Filename to Clipboard", "", "Copies the full path and filename to the clipboard", G_CALLBACK(copy_filename_to_clipboard_cb) },
 	{ "PropertiesPopupAction", GTK_STOCK_PROPERTIES, "File Properties", "", "Show file properties", G_CALLBACK(file_properties_cb) }
 
 };
@@ -795,16 +799,11 @@ EXITPOINT:
 static void sort_ascending_cb()
 {
 	GError *err = NULL;	
-	GtkTreeIter *nodeIter=NULL;
 	
 	if (clicked_node.valid && clicked_node.type==ITEMTYPE_FILE) {
 		goto EXITPOINT;
 	}
-	
-	if (clicked_node.valid) {
-		nodeIter=&(clicked_node.iter);
-	}
-	
+
 	sort_children(&(clicked_node.iter),&err,compare_strings_smaller);
 	
 	
@@ -819,16 +818,11 @@ EXITPOINT:
 static void sort_descending_cb()
 {
 	GError *err = NULL;	
-	GtkTreeIter *nodeIter=NULL;
 	
 	if (clicked_node.valid && clicked_node.type==ITEMTYPE_FILE) {
 		goto EXITPOINT;
 	}
 	
-	if (clicked_node.valid) {
-		nodeIter=&(clicked_node.iter);
-	}
-	
 	sort_children(&clicked_node.iter,&err,compare_strings_bigger);
 	
 	
@@ -1003,10 +997,6 @@ void remove_selected_items ( GtkTreeView *treeview )
 	
 	list=g_list_last(list);
 	while(list) {
-
-		int ipath=(int)(strtoll(gtk_tree_path_to_string((GtkTreePath*)(list->data)),NULL,10));
-
-		ipath-=nRemoved;
 		GString *fixed_path = g_string_new("");
 		g_string_printf(fixed_path, "%s", gtk_tree_path_to_string((GtkTreePath*)list->data)/*ipath*/);
 
@@ -1374,9 +1364,6 @@ static void row_expand_or_collapse_cb(GtkTreeView *tree_view, GtkTreeIter *iter,
 {
 	/* Switch the folder icon open/closed*/
 	
-	GtkTreeModel *tree_model = NULL;
-	tree_model = gtk_tree_view_get_model(tree_view);
-	
 	
 	// make sure all icons the folder (and folders inside it) are set to a correct icon.
 	fix_folders_step_through(tree_view,*iter,tree_path);
@@ -1719,6 +1706,69 @@ void edit_options_cb()
 }
 
 
+
+
+/**
+ * Copies the filename including full folder to the clipboard
+ */
+void copy_filename_to_clipboard(GtkTreeModel *model, GtkTreeIter *iter)
+{
+	GError *err=NULL;
+	
+	gchar *nodename=NULL;
+	gchar *filePath=NULL;
+	int nodeType=-1;
+	
+	gtk_tree_model_get(model, iter, COLUMN_FILENAME, &nodename, COLUMN_ITEMTYPE, &nodeType, COLUMN_FILEPATH, &filePath, -1);
+	
+	gchar *absFilePath = NULL; //g_strdup_printf("%s",filePath);
+		
+	// filePath is NULL?
+	//if (!relative_path_to_abs_path(sClickedNodeName, &absFilePath, get_project_directory(), &err)) {
+	
+	if (!relative_path_to_abs_path(filePath, &absFilePath, get_project_directory(), &err)) {
+		goto EXITPOINT;
+	}
+	
+	GdkDisplay *display=gdk_display_get_default();
+	
+	GtkClipboard *clipboard=gtk_clipboard_get_for_display(display,GDK_SELECTION_CLIPBOARD);
+	
+	gtk_clipboard_set_text(clipboard,absFilePath,-1);
+	
+EXITPOINT:
+	
+	if (err) g_error_free(err);
+}
+
+
+/**
+ * Callback for the menu item
+ */
+void copy_filename_to_clipboard_cb()
+{
+	gint selected_rows=0;
+	gboolean multiple_selected=FALSE;
+	
+	GtkTreeSelection *treeSelect;
+	
+	treeSelect=gtk_tree_view_get_selection(GTK_TREE_VIEW(sTreeView));
+	
+	selected_rows=gtk_tree_selection_count_selected_rows(treeSelect);
+	if (selected_rows>1) {
+		multiple_selected=TRUE;
+	}
+		
+	if (!clicked_node.valid || clicked_node.type != ITEMTYPE_FILE) {
+		//goto EXITPOINT;
+	} else {
+		copy_filename_to_clipboard(gtk_tree_view_get_model(GTK_TREE_VIEW(sTreeView)),&(clicked_node.iter));
+		
+	}
+}
+
+
+
 /**
  *
  */
