@@ -106,8 +106,8 @@ int main(int argc, char *argv[])
 			gPrefs.scite_path=g_strdup(cmd.scite_filename);
 			
 		} else {
-			g_print("SciTE file %s doesn't exist!\n",cmd.scite_filename);
-			g_print("Checking for SciTE in the standrad locations instead.\n");
+			g_print("Couldn't find a SciTE executable named '%s'!\n",cmd.scite_filename);
+			g_print("Checking for SciTE in the standard locations instead.\n");
 		}
 	} 
 	
@@ -265,9 +265,11 @@ static void parse_cmd_options(int argc,char *argv[])
 		}
 	}
 	
+#ifdef _DEBUG
 	if (cmd.scite_filename!=NULL) {
 		g_print("scite_filename:%s\n",cmd.scite_filename);
 	}
+#endif
 	
 	if (indata_left!=NULL) {
 		cmd.file_to_load=g_strdup(indata_left);
